Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(406)

Unified Diff: base/trace_event/malloc_dump_provider.cc

Issue 1191893002: [tracing] Fix malloc accounting in memory-infra (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 5 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: base/trace_event/malloc_dump_provider.cc
diff --git a/base/trace_event/malloc_dump_provider.cc b/base/trace_event/malloc_dump_provider.cc
index 92d513f99d3e311bef9aecce5d3a186736a78957..3e593b02897cb9ce8477765858469f5c4160d402 100644
--- a/base/trace_event/malloc_dump_provider.cc
+++ b/base/trace_event/malloc_dump_provider.cc
@@ -32,13 +32,13 @@ bool MallocDumpProvider::OnMemoryDump(ProcessMemoryDump* pmd) {
struct mallinfo info = mallinfo();
DCHECK_GE(info.arena + info.hblkhd, info.uordblks);
// When the system allocator is implemented by tcmalloc, the total physical
// size is given by |arena| and |hblkhd| is 0. In case of Android's jemalloc
// |arena| is 0 and the outer pages size is reported by |hblkhd|. In case of
// dlmalloc the total is given by |arena| + |hblkhd|.
// For more details see link: http://goo.gl/fMR8lF.
MemoryAllocatorDump* outer_dump = pmd->CreateAllocatorDump("malloc");
- outer_dump->AddScalar(MemoryAllocatorDump::kNameSize,
+ outer_dump->AddScalar("heap_virtual_size",
MemoryAllocatorDump::kUnitsBytes,
info.arena + info.hblkhd);
« no previous file with comments | « no previous file | no next file » | no next file with comments »
@@ -32,13 +32,13 @@ bool MallocDumpProvider::OnMemoryDump(ProcessMemoryDump* pmd) {
struct mallinfo info = mallinfo();
DCHECK_GE(info.arena + info.hblkhd, info.uordblks);
- // When the system allocator is implemented by tcmalloc, the total physical
+ // When the system allocator is implemented by tcmalloc, the total heap
// size is given by |arena| and |hblkhd| is 0. In case of Android's jemalloc
// |arena| is 0 and the outer pages size is reported by |hblkhd|. In case of

Powered by Google App Engine
This is Rietveld 408576698